@@ -4,7 +4,8 @@ Python library for Italian fiscal code
 codicefiscale is a Python library for working with Italian fiscal code numbers
 officially known as Italy's Codice Fiscale.
 
-Copyright (C) 2009-2012 Emanuele Rocca
+Copyright (C) 2009-2013 Emanuele Rocca
+
 Homepage: https://github.com/ema/pycodicefiscale
 
 This library is free software; you can redistribute it and/or
@@ -22,10 +23,11 @@ License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-__version__ = '0.7'
+__version__ = '0.8'
 __author__ = "Emanuele Rocca"
 
 import re
+# pylint: disable=W0402
 import string
 
 __VOWELS = [ 'A', 'E', 'I', 'O', 'U' ]
@@ -33,6 +35,7 @@ __CONSONANTS = list(set(list(string.ascii_uppercase)).difference(__VOWELS))
 
 MONTHSCODE = [ 'A', 'B', 'C', 'D', 'E', 'H', 'L', 'M', 'P', 'R', 'S', 'T' ]
 
+# pylint: disable=C0301
 PATTERN = "^[A-Z]{6}[0-9]{2}([A-E]|[HLMPRST])[0-9]{2}[A-Z][0-9]([A-Z]|[0-9])[0-9][A-Z]$"
 
 def isvalid(code):
@@ -41,8 +44,9 @@ def isvalid(code):
     This function checks if the given fiscal code is syntactically valid.
 
     eg: isvalid('RCCMNL83S18D969H') -> True
-        isvalid('RCCMNL83S18D969') -> False"""
-    return type(code) is str and re.match(PATTERN, code) is not None
+        isvalid('RCCMNL83S18D969') -> False
+    """
+    return isinstance(code, basestring) and re.match(PATTERN, code) is not None
 
 # Fiscal code calculation 
 def __common_triplet(input_string, consonants, vowels):
@@ -87,7 +91,8 @@ def __name_triplet(input_string):
     if input_string == '':
         # highly unlikely: no first name, like for instance some Indian persons
         # with only one name on the passport
-        return 'XXX'
+        # pylint: disable=W0511
+        return 'XXX' 
 
     consonants, vowels = __consonants_and_vowels(input_string)
     
@@ -102,7 +107,8 @@ def control_code(input_string):
     Computes the control code for the given input_string string. The expected
     input_string is the first 15 characters of a fiscal code.
 
-    eg: control_code('RCCMNL83S18D969') -> 'H'"""
+    eg: control_code('RCCMNL83S18D969') -> 'H'
+    """
     assert len(input_string) == 15
 
     # building conversion tables for even and odd characters positions
@@ -141,7 +147,8 @@ def build(surname, name, birthday, sex, municipality):
     Computes the fiscal code for the given person data.
 
     eg: build('Rocca', 'Emanuele', datetime.datetime(1983, 11, 18), 'M', 'D969') 
-        -> RCCMNL83S18D969H"""
+        -> RCCMNL83S18D969H
+    """
 
     # RCCMNL
     output = __surname_triplet(surname) + __name_triplet(name)
@@ -169,14 +176,14 @@ def build(surname, name, birthday, sex, municipality):
 def get_birthday(code):
     """``get_birthday(code) -> string``
 
-    The birthday of the person whose fiscal code is 'code', in the format
-    DD-MM-YY. 
+    Birthday of the person whose fiscal code is 'code', in the format DD-MM-YY. 
 
     Unfortunately it's not possible to guess the four digit birth year, given
     that the Italian fiscal code uses only the last two digits (1983 -> 83).
     Therefore, this function returns a string and not a datetime object.
 
-    eg: birthday('RCCMNL83S18D969H') -> 18-11-83"""
+    eg: birthday('RCCMNL83S18D969H') -> 18-11-83
+    """
     assert isvalid(code)
 
     day = int(code[9:11])
@@ -193,7 +200,8 @@ def get_sex(code):
     The sex of the person whose fiscal code is 'code'.
 
     eg: sex('RCCMNL83S18D969H') -> 'M'
-        sex('CNTCHR83T41D969D') -> 'F'"""
+        sex('CNTCHR83T41D969D') -> 'F'
+    """
     
     assert isvalid(code)
 
